@@ -157,6 +157,7 @@ modest_hildon2_global_settings_dialog_init (ModestHildon2GlobalSettingsDialog *s
 	gtk_container_add (GTK_CONTAINER (GTK_DIALOG (self)->vbox), align);
 	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (self)->vbox), MODEST_MARGIN_HALF);
 	gtk_window_set_default_size (GTK_WINDOW (self), -1, MODEST_DIALOG_WINDOW_MAX_HEIGHT);
+	gtk_widget_set_size_request (GTK_WIDGET (self), -1, MODEST_DIALOG_WINDOW_MAX_HEIGHT);
 
 	gtk_widget_show (align);
 	gtk_widget_show (top_vbox);
@@ -210,7 +211,8 @@ create_updating_page (ModestHildon2GlobalSettingsDialog *self)
 	ppriv->accounts_list = get_accounts_list ();
 	ppriv->default_account_selector = modest_toolkit_factory_create_selector (modest_runtime_get_toolkit_factory (),
 										  ppriv->accounts_list,
-										  g_str_equal);
+										  g_str_equal,
+										  TRUE);
 	if (ppriv->accounts_list == NULL) {
 		gtk_widget_set_sensitive (GTK_WIDGET (ppriv->default_account_selector), FALSE);
 	} else {
@@ -247,7 +249,8 @@ create_updating_page (ModestHildon2GlobalSettingsDialog *self)
 	 * so it can't know how to manage its memory. */
 	ppriv->msg_format_list = _modest_global_settings_dialog_get_msg_formats ();
 	ppriv->msg_format = modest_toolkit_factory_create_selector (modest_runtime_get_toolkit_factory (),
-								    ppriv->msg_format_list, g_int_equal);
+								    ppriv->msg_format_list, g_int_equal,
+								    TRUE);
 	if (GTK_IS_COMBO_BOX (ppriv->msg_format)) {
 		GtkWidget *caption;
 		caption = modest_toolkit_utils_create_vcaptioned (title_size_group,
@@ -275,6 +278,12 @@ create_updating_page (ModestHildon2GlobalSettingsDialog *self)
 	gtk_button_set_alignment (GTK_BUTTON (ppriv->add_to_contacts), 0.0, 0.5);
 	gtk_box_pack_start (GTK_BOX (vbox), ppriv->add_to_contacts, FALSE, FALSE, 0);
 
+	/* Tree view mode */
+	ppriv->tree_view = hildon_check_button_new (MODEST_EDITABLE_SIZE);
+	gtk_button_set_label (GTK_BUTTON (ppriv->tree_view), _("mcen_fi_options_tree_view"));
+	gtk_button_set_alignment (GTK_BUTTON (ppriv->tree_view), 0.0, 0.5);
+	gtk_box_pack_start (GTK_BOX (vbox), ppriv->tree_view, FALSE, FALSE, 0);
+
 	/* Separator label */
 	separator = gtk_label_new (_("mcen_ti_updating"));
 	gtk_label_set_justify ((GtkLabel *) separator, GTK_JUSTIFY_CENTER);
@@ -293,7 +302,8 @@ create_updating_page (ModestHildon2GlobalSettingsDialog *self)
 	 * so it can't know how to manage its memory. */ 
 	ppriv->connect_via_list = _modest_global_settings_dialog_get_connected_via ();
 	ppriv->connect_via = modest_toolkit_factory_create_selector (modest_runtime_get_toolkit_factory (),
-								     ppriv->connect_via_list, g_int_equal);
+								     ppriv->connect_via_list, g_int_equal,
+								     TRUE);
 	if (GTK_IS_COMBO_BOX (ppriv->connect_via)) {
 		GtkWidget *caption;
 		caption = modest_toolkit_utils_create_vcaptioned (title_size_group,
@@ -315,7 +325,7 @@ create_updating_page (ModestHildon2GlobalSettingsDialog *self)
 	 * so it can't know how to manage its memory. */ 
 	ppriv->update_interval_list = _modest_global_settings_dialog_get_update_interval ();
 	ppriv->update_interval = modest_toolkit_factory_create_selector (modest_runtime_get_toolkit_factory (),
-									 ppriv->update_interval_list, g_int_equal);
+									 ppriv->update_interval_list, g_int_equal, TRUE);
 	if (GTK_IS_COMBO_BOX (ppriv->update_interval)) {
 		GtkWidget *caption;
 		caption = modest_toolkit_utils_create_vcaptioned (title_size_group,
@@ -332,6 +342,7 @@ create_updating_page (ModestHildon2GlobalSettingsDialog *self)
 
 	scrollable = modest_toolkit_factory_create_scrollable (modest_runtime_get_toolkit_factory ());
 
+	g_object_set (scrollable, "mov-mode", HILDON_MOVEMENT_MODE_BOTH, NULL);
 	modest_scrollable_add_with_viewport (MODEST_SCROLLABLE (scrollable), vbox);
 	gtk_widget_show (vbox);
 	gtk_widget_show (scrollable);
@@ -477,6 +488,16 @@ modest_hildon2_global_settings_dialog_load_settings (ModestGlobalSettingsDialog
 	hildon_check_button_set_active (HILDON_CHECK_BUTTON (ppriv->add_to_contacts), checked);
 	ppriv->initial_state.add_to_contacts = checked;
 
+	/* Tree view mode */
+	checked = modest_conf_get_bool (conf, MODEST_CONF_TREE_VIEW, &error);
+	if (error) {
+		g_clear_error (&error);
+		error = NULL;
+		checked = FALSE;
+	}
+	hildon_check_button_set_active (HILDON_CHECK_BUTTON (ppriv->tree_view), checked);
+	ppriv->initial_state.tree_view = checked;
+
 	/* Autoupdate */
 	checked = modest_conf_get_bool (conf, MODEST_CONF_AUTO_UPDATE, &error);
 	if (error) {
