@@ -97,7 +97,7 @@
 #define HILDON_OSSO_URI_ACTION "uri-action"
 #define URI_ACTION_COPY "copy:"
 #define MODEST_NOTIFICATION_CATEGORY "email-message"
-#define MODEST_NEW_MAIL_LIGHTING_PATTERN "PatternChatAndEmail"
+#define MODEST_NEW_MAIL_LIGHTING_PATTERN "PatternCommunicationEmail"
 #ifdef MODEST_USE_PROFILE
 #define PROFILE_MAIL_TONE PROFILEKEY_EMAIL_ALERT_TONE
 #define PROFILE_MAIL_VOLUME PROFILEKEY_EMAIL_ALERT_VOLUME
@@ -1284,6 +1284,9 @@ modest_platform_run_information_dialog (GtkWindow *parent_window,
 					     GTK_WINDOW (note), parent_window);
 	
 	if (block) {
+		while (gtk_events_pending ()) {
+			gtk_main_iteration ();
+		}
 		gtk_dialog_run (GTK_DIALOG (note));
 	
 		on_destroy_dialog (note);
@@ -1728,7 +1731,7 @@ modest_platform_remove_new_mail_notifications (gboolean only_visuals, const gcha
 						  MODEST_ACCOUNT_NOTIFICATION_IDS, 
 						  MODEST_CONF_VALUE_INT, FALSE);
 
-        while (notif_list) {
+	while (notif_list) {
 		gint notif_id;
 		NotifyNotification *notif;
 
@@ -1746,15 +1749,11 @@ modest_platform_remove_new_mail_notifications (gboolean only_visuals, const gcha
 
 		/* Delete the link, it's like going to the next */
 		notif_list = g_slist_delete_link (notif_list, notif_list);
-        }
+	}
 
-	/* Save the ids */
+	/* Reset the ids */
 	modest_account_mgr_set_list (modest_runtime_get_account_mgr (), acc_name,
-				     MODEST_ACCOUNT_NOTIFICATION_IDS,
-				     notif_list, MODEST_CONF_VALUE_INT, FALSE);
-
-	g_slist_free (notif_list);
-
+		MODEST_ACCOUNT_NOTIFICATION_IDS, NULL, MODEST_CONF_VALUE_INT, FALSE);
 #endif /* MODEST_HAVE_HILDON_NOTIFY */
 }
 
@@ -1806,8 +1805,11 @@ modest_platform_create_folder_view_full (TnyFolderStoreQuery *query, gboolean do
 {
 	GtkWidget *widget = modest_folder_view_new_full (query, do_refresh);
 
-	/* Show one account by default */
+	/* Show one account in list mode, all accounts in tree view mode */
 	modest_folder_view_set_style (MODEST_FOLDER_VIEW (widget),
+				      modest_conf_get_bool (modest_runtime_get_conf (),
+					              	    MODEST_CONF_TREE_VIEW, NULL) ?
+				      MODEST_FOLDER_VIEW_STYLE_SHOW_ALL :
 				      MODEST_FOLDER_VIEW_STYLE_SHOW_ONE);
 
 	return widget;
@@ -2701,6 +2703,7 @@ modest_platform_play_email_tone (void)
 #define MOVE_TO_DIALOG_BACK_BUTTON "back-button"
 #define MOVE_TO_DIALOG_ACTION_BUTTON "action-button"
 #define MOVE_TO_DIALOG_SHOWING_FOLDERS "showing-folders"
+#define MOVE_TO_DIALOG_TREE_VIEW "tree-view"
 #define MOVE_TO_DIALOG_SCROLLABLE "scrollable"
 #define MOVE_TO_FOLDER_SEPARATOR "/"
 
@@ -2803,7 +2806,9 @@ move_to_dialog_set_selected_folder_store (GtkWidget *dialog,
 		translate_path (&full_name);
 		hildon_button_set_value (HILDON_BUTTON (action_button), full_name);
 		g_free (full_name);
-	}
+	} else
+		hildon_button_set_value (HILDON_BUTTON (action_button), NULL);
+		
 	g_free (account_name);
 	g_free (short_name);
 
@@ -2820,6 +2825,7 @@ move_to_dialog_show_accounts (GtkWidget *dialog)
 	GtkWidget *folder_view;
 	GtkWidget *scrollable;
 	GtkWidget *action_button;
+	gboolean tree_view_mode;
 
         back_button = GTK_WIDGET (g_object_get_data (G_OBJECT (dialog), MOVE_TO_DIALOG_BACK_BUTTON));
         action_button = GTK_WIDGET (g_object_get_data (G_OBJECT (dialog), MOVE_TO_DIALOG_ACTION_BUTTON));
@@ -2847,8 +2853,13 @@ move_to_dialog_show_accounts (GtkWidget *dialog)
 				       MODEST_FOLDER_VIEW_FILTER_HIDE_LOCAL_FOLDERS);
 	modest_folder_view_unset_filter (MODEST_FOLDER_VIEW (folder_view), 
 					 MODEST_FOLDER_VIEW_FILTER_HIDE_ACCOUNTS);
-	modest_folder_view_set_filter (MODEST_FOLDER_VIEW (folder_view), 
-				       MODEST_FOLDER_VIEW_FILTER_HIDE_FOLDERS);
+
+	tree_view_mode = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (dialog), MOVE_TO_DIALOG_TREE_VIEW));
+
+	if (!tree_view_mode)
+		modest_folder_view_set_filter (MODEST_FOLDER_VIEW (folder_view), 
+				       	       MODEST_FOLDER_VIEW_FILTER_HIDE_FOLDERS);
+
 	modest_scrollable_jump_to (MODEST_SCROLLABLE (scrollable), 0, 0);
 }
 
@@ -2927,12 +2938,15 @@ on_move_to_dialog_row_activated (GtkTreeView       *tree_view,
 	TnyFolderStore *selected = NULL;
 	GtkWidget *dialog;
 	GtkWidget *folder_view;
-	gboolean showing_folders;
+	gboolean showing_folders, tree_view_mode;
 
 	dialog = (GtkWidget *) user_data;
 	showing_folders = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (dialog), 
 							      MOVE_TO_DIALOG_SHOWING_FOLDERS));
 
+	tree_view_mode = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (dialog), 
+							      MOVE_TO_DIALOG_TREE_VIEW));
+
 	folder_view = GTK_WIDGET (g_object_get_data (G_OBJECT (dialog), 
 						     MOVE_TO_DIALOG_FOLDER_VIEW));
 
@@ -2940,23 +2954,35 @@ on_move_to_dialog_row_activated (GtkTreeView       *tree_view,
 	if (!selected)
 		return;
 
-	if (!showing_folders) {
-		gboolean valid = TRUE;
+	if (tree_view_mode) {
+        	GtkWidget *back_button =
+			GTK_WIDGET (g_object_get_data (G_OBJECT (dialog), MOVE_TO_DIALOG_BACK_BUTTON));
+        	GtkWidget *action_button =
+			GTK_WIDGET (g_object_get_data (G_OBJECT (dialog), MOVE_TO_DIALOG_ACTION_BUTTON));
+        	move_to_dialog_set_selected_folder_store (dialog, selected);
+		gtk_widget_set_sensitive (back_button, TRUE);
+		gtk_widget_set_sensitive (action_button, TRUE);
+	}
+	else {
 
-		if (TNY_IS_ACCOUNT (selected) &&
-		    modest_tny_folder_store_is_remote (TNY_FOLDER_STORE (selected))) {
-			ModestProtocolType protocol_type;
+		if (!showing_folders) {
+			gboolean valid = TRUE;
 
-			protocol_type = modest_tny_account_get_protocol_type (TNY_ACCOUNT (selected));
-			valid  = !modest_protocol_registry_protocol_type_has_tag 
-				(modest_runtime_get_protocol_registry (),
-				 protocol_type,
-				 MODEST_PROTOCOL_REGISTRY_STORE_FORBID_INCOMING_XFERS);
+			if (TNY_IS_ACCOUNT (selected) &&
+		    	    modest_tny_folder_store_is_remote (TNY_FOLDER_STORE (selected))) {
+				ModestProtocolType protocol_type;
+
+				protocol_type = modest_tny_account_get_protocol_type (TNY_ACCOUNT (selected));
+				valid  = !modest_protocol_registry_protocol_type_has_tag 
+					(modest_runtime_get_protocol_registry (),
+				 	 protocol_type,
+				 	 MODEST_PROTOCOL_REGISTRY_STORE_FORBID_INCOMING_XFERS);
+			}
+			if (valid)
+				move_to_dialog_show_folders (dialog, selected);
+		} else {
+			move_to_dialog_set_selected_folder_store (dialog, selected);
 		}
-		if (valid)
-			move_to_dialog_show_folders (dialog, selected);
-	} else {
-		move_to_dialog_set_selected_folder_store (dialog, selected);
 	}
 	g_object_unref (selected);
 }
@@ -2989,11 +3015,13 @@ on_move_to_dialog_action_clicked (GtkButton *selection,
 				  gpointer   user_data)
 {
 	GtkWidget *dialog;
-	gboolean showing_folders;
+	gboolean showing_folders, tree_view_mode;
 
 	dialog = (GtkWidget *) user_data;
 	showing_folders = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (dialog), MOVE_TO_DIALOG_SHOWING_FOLDERS));
-	if (showing_folders) {
+	tree_view_mode = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (dialog), MOVE_TO_DIALOG_TREE_VIEW));
+
+	if (showing_folders || tree_view_mode) {
 		TnyFolderStore *selected;
 		GtkWidget *folder_view;
 
@@ -3032,6 +3060,7 @@ modest_platform_create_move_to_dialog (GtkWindow *parent_window,
 	GtkWidget *top_vbox;
 	GtkWidget *action_button;
 	GtkTreeSelection *selection;
+	gboolean tree_view_mode;
 
 	/* Create dialog. We cannot use a touch selector because we
 	   need to use here the folder view widget directly */
@@ -3039,7 +3068,7 @@ modest_platform_create_move_to_dialog (GtkWindow *parent_window,
 					      GTK_WINDOW (parent_window),
 					      GTK_DIALOG_MODAL | GTK_DIALOG_NO_SEPARATOR |
 					      GTK_DIALOG_DESTROY_WITH_PARENT,
-					      _FM_CHANGE_FOLDER_NEW_FOLDER,
+					      _FM ("ckdg_bd_change_folder_new_folder"),
 					      MODEST_GTK_RESPONSE_NEW_FOLDER,
 	                                      NULL);
 
@@ -3102,6 +3131,9 @@ modest_platform_create_move_to_dialog (GtkWindow *parent_window,
 	g_object_set_data (G_OBJECT (dialog), MOVE_TO_DIALOG_ACTION_BUTTON, action_button);
 	g_object_set_data (G_OBJECT (dialog), MOVE_TO_DIALOG_SCROLLABLE, folder_view_container);
 
+	tree_view_mode = modest_conf_get_bool (modest_runtime_get_conf (), MODEST_CONF_TREE_VIEW, NULL);
+	g_object_set_data (G_OBJECT (dialog), MOVE_TO_DIALOG_TREE_VIEW, GINT_TO_POINTER (tree_view_mode));
+
         /* Simulate the behaviour of a HildonPickerDialog by emitting
 	   a response when a folder is selected */
         g_signal_connect (*folder_view, "row-activated",
@@ -3163,3 +3195,60 @@ modest_platform_get_list_to_move (ModestWindow *window)
 
 	return list;
 }
+
+DBusConnection*
+modest_platform_get_dbus_connection (void)
+{
+	osso_context_t *osso_context;
+	DBusConnection *con;
+
+	osso_context = modest_maemo_utils_get_osso_context();
+
+	con = osso_get_dbus_connection (osso_context);
+
+	return con;
+}
+
+void
+modest_platform_emit_folder_updated_signal (const gchar *account_id, const gchar *folder_id)
+{
+	DBusConnection *con;
+
+	con = modest_platform_get_dbus_connection ();
+	if (!con) return;
+
+	modest_dbus_emit_folder_updated_signal (con, account_id, folder_id);
+}
+
+void
+modest_platform_emit_account_created_signal (const gchar *account_id)
+{
+	DBusConnection *con;
+
+	con = modest_platform_get_dbus_connection ();
+	if (!con) return;
+
+	modest_dbus_emit_account_created_signal (con, account_id);
+}
+
+void
+modest_platform_emit_account_removed_signal (const gchar *account_id)
+{
+	DBusConnection *con;
+
+	con = modest_platform_get_dbus_connection ();
+	if (!con) return;
+
+	modest_dbus_emit_account_removed_signal (con, account_id);
+}
+void
+modest_platform_emit_msg_read_changed_signal (const gchar *msg_uid,
+					      gboolean is_read)
+{
+	DBusConnection *con;
+
+	con = modest_platform_get_dbus_connection ();
+	if (!con) return;
+
+	modest_dbus_emit_msg_read_changed_signal (con, msg_uid, is_read);
+}
