@@ -35,6 +35,7 @@
 #include <modest-account-mgr-priv.h>
 #include <modest-account-mgr-helpers.h>
 #include <modest-platform.h>
+#include "modest-tny-account.h"
 
 /* 'private'/'protected' functions */
 static void modest_account_mgr_class_init (ModestAccountMgrClass * klass);
@@ -342,6 +343,7 @@ modest_account_mgr_add_account_from_settings (ModestAccountMgr *self,
 				
 	/* Notify the observers */
 	g_signal_emit (self, signals[ACCOUNT_INSERTED_SIGNAL], 0, account_name);
+	modest_platform_emit_account_created_signal (account_name);
 
 	/* if no default account has been defined yet, do so now */
 	default_account = modest_account_mgr_get_default_account (self);
@@ -456,6 +458,7 @@ modest_account_mgr_add_account (ModestAccountMgr *self,
 
 	/* Notify the observers */
 	g_signal_emit (self, signals[ACCOUNT_INSERTED_SIGNAL], 0, name);
+	modest_platform_emit_account_created_signal (name);
 
 	/* if no default account has been defined yet, do so now */
 	default_account = modest_account_mgr_get_default_account (self);
@@ -717,6 +720,7 @@ modest_account_mgr_remove_account (ModestAccountMgr * self,
 	   the keys, because otherwise a call to account_names
 	   will retrieve also the deleted account */
 	g_signal_emit (G_OBJECT(self), signals[ACCOUNT_REMOVED_SIGNAL], 0, name);
+	modest_platform_emit_account_removed_signal (name);
 	
 	return TRUE;
 }
@@ -1072,6 +1076,13 @@ modest_account_mgr_set_bool (ModestAccountMgr * self, const gchar * name,
 		g_printerr ("modest: error setting bool '%s': %s\n", keyname, err->message);
 		g_error_free (err);
 		retval = FALSE;
+	} else {
+		/* check whether this field is one of those interesting for the 
+		 * "account-updated" signal */
+		if (strcmp (key, MODEST_ACCOUNT_HAS_NEW_MAILS) == 0) {
+			g_signal_emit (G_OBJECT(self), signals[ACCOUNT_UPDATED_SIGNAL], 
+					0, name);
+		}
 	}
 
 	return retval;
@@ -1094,7 +1105,6 @@ modest_account_mgr_set_list (ModestAccountMgr *self,
 	g_return_val_if_fail (self, FALSE);
 	g_return_val_if_fail (name, FALSE);
 	g_return_val_if_fail (key,  FALSE);
-	g_return_val_if_fail (val,  FALSE);
 
 	priv = MODEST_ACCOUNT_MGR_GET_PRIVATE (self);
 
@@ -1465,7 +1475,7 @@ modest_account_mgr_has_accounts (ModestAccountMgr* self, gboolean enabled)
 	
 	if (enabled && priv->has_enabled_accounts)
 		return TRUE;
-	else if (priv->has_accounts)
+	else if (!enabled && priv->has_accounts)
 		return TRUE;
 		
 	/* Check that at least one account exists: */
@@ -1706,3 +1716,24 @@ modest_account_mgr_singleton_protocol_exists (ModestAccountMgr *mgr,
 
 	return found;
 }
+
+gchar*
+modest_account_mgr_get_account_from_tny_account  (ModestAccountMgr *self,
+						  TnyAccount *account)
+{
+	gchar *account_name = NULL;
+	GSList *account_names = modest_account_mgr_account_names(self, TRUE);
+	GSList *cursor = account_names;
+	while (cursor) {
+		const gchar *store = modest_account_mgr_get_string(self,(gchar *)cursor->data,
+						"store_account",FALSE);
+		if (!strcmp(store,tny_account_get_id(TNY_ACCOUNT(account)))) {
+			account_name = g_strdup((gchar *)cursor->data);
+			break;
+		}
+		cursor = cursor -> next;
+	}
+	
+	modest_account_mgr_free_account_names (account_names);
+	return  account_name;
+}
