@@ -731,10 +731,14 @@ init_default_settings (ModestConf *conf)
 		modest_conf_set_bool (conf, MODEST_CONF_MSG_VIEW_WINDOW_SHOW_TOOLBAR_FULLSCREEN, TRUE, NULL);
 
 	if (!modest_conf_key_exists (conf, MODEST_CONF_EDIT_WINDOW_SHOW_TOOLBAR, NULL))
-		modest_conf_set_bool (conf, MODEST_CONF_EDIT_WINDOW_SHOW_TOOLBAR, TRUE, NULL);
+		modest_conf_set_bool (conf, MODEST_CONF_EDIT_WINDOW_SHOW_TOOLBAR, FALSE, NULL);
 	
 	if (!modest_conf_key_exists (conf, MODEST_CONF_EDIT_WINDOW_SHOW_TOOLBAR_FULLSCREEN, NULL))
-		modest_conf_set_bool (conf, MODEST_CONF_EDIT_WINDOW_SHOW_TOOLBAR_FULLSCREEN, TRUE, NULL);
+		modest_conf_set_bool (conf, MODEST_CONF_EDIT_WINDOW_SHOW_TOOLBAR_FULLSCREEN, FALSE, NULL);
+
+	if (!modest_conf_key_exists (conf, MODEST_CONF_FOLDER_VIEW_WINDOW_TREE_VIEW_INDENTATION, NULL))
+		modest_conf_set_int (conf, MODEST_CONF_FOLDER_VIEW_WINDOW_TREE_VIEW_INDENTATION, 
+				MODEST_DEFAULT_TREE_VIEW_INDENTATION, NULL);
 
 	/* Editor keys */
 	if (!modest_conf_key_exists (conf, MODEST_CONF_SHOW_CC, NULL))
@@ -761,6 +765,9 @@ init_default_settings (ModestConf *conf)
 	if (!modest_conf_key_exists (conf, MODEST_CONF_AUTO_ADD_TO_CONTACTS, NULL))
 		modest_conf_set_bool (conf, MODEST_CONF_AUTO_ADD_TO_CONTACTS, TRUE, NULL);
 
+	if (!modest_conf_key_exists (conf, MODEST_CONF_TREE_VIEW, NULL))
+		modest_conf_set_bool (conf, MODEST_CONF_TREE_VIEW, FALSE, NULL);
+
 	if (!modest_conf_key_exists (conf, MODEST_CONF_UPDATE_WHEN_CONNECTED_BY, NULL))
 		modest_conf_set_int (conf, MODEST_CONF_UPDATE_WHEN_CONNECTED_BY, MODEST_CONNECTED_VIA_WLAN_OR_WIMAX, NULL);
 
