@@ -80,6 +80,7 @@ typedef enum {
 	MODEST_MAIL_OPERATION_TYPE_QUEUE_WAKEUP,
 	MODEST_MAIL_OPERATION_TYPE_UPDATE_FOLDER_COUNTS,
 	MODEST_MAIL_OPERATION_TYPE_UNKNOWN,
+	MODEST_MAIL_OPERATION_TYPE_DISCONNECT_ACCOUNT,
 } ModestMailOperationTypeOperation;
 
 /**
@@ -399,6 +400,9 @@ void    modest_mail_operation_send_new_mail   (ModestMailOperation *self,
 					       const gchar *in_reply_to,
 					       TnyHeaderFlags priority_flags);
 
+void modest_mail_operation_send_mail (ModestMailOperation *mail_operation,
+				      TnyTransportAccount *transport_account,
+				      TnyMsg *msg);
 
 /**
  * modest_mail_operation_save_to_drafts:
@@ -848,6 +852,12 @@ TnyAccount *modest_mail_operation_get_account   (ModestMailOperation *self);
  **/
 void modest_mail_operation_noop (ModestMailOperation *self);
 
+/**
+ * modest_mail_operation_disconnect_account:
+ * @param[in] self The pointer to the ModestMailOperation instance
+ * @param[in] account The pointer to the TnyAccount to be disconnected
+ */
+void modest_mail_operation_disconnect_account (ModestMailOperation *self, TnyAccount *account);
 
 /**
  * modest_mail_operation_to_string:
