@@ -35,6 +35,7 @@
 #include "widgets/modest-folder-view.h"
 #include "widgets/modest-sort-criterium-view.h"
 #ifdef MODEST_PLATFORM_MAEMO
+#include <dbus/dbus.h>
 #include <libosso.h>
 #endif
 
@@ -561,6 +562,15 @@ GtkWidget* modest_platform_create_move_to_dialog (GtkWindow *parent_window,
 
 TnyList* modest_platform_get_list_to_move (ModestWindow *window);
 
+#ifdef MODEST_PLATFORM_MAEMO
+DBusConnection* modest_platform_get_dbus_connection (void);
+#endif
+
+void modest_platform_emit_folder_updated_signal (const gchar *account_id, const gchar *folder_id);
+void modest_platform_emit_account_created_signal (const gchar *account_id);
+void modest_platform_emit_account_removed_signal (const gchar *account_id);
+void modest_platform_emit_msg_read_changed_signal (const gchar *msg_uid, gboolean is_read);
+
 G_END_DECLS
 
 #endif /* __MODEST_PLATFORM_UTILS_H__ */
