@@ -130,8 +130,7 @@ modest_utils_create_temp_stream (const gchar *orig_name, const gchar *hash_base,
 
 	/* hmmm... maybe we need a modest_text_utils_validate_file_name? */
 	g_return_val_if_fail (orig_name && strlen(orig_name) != 0, NULL);
-
-	if (strlen(orig_name) > 200) {
+	if (strlen(orig_name) > 254) {
 		g_warning ("%s: filename too long ('%s')",
 			   __FUNCTION__, orig_name);
 		return NULL;
@@ -548,6 +547,7 @@ launch_sort_headers_dialog (ModestWindow *parent_window,
 	gint attachments_sort_id;
 	gint priority_sort_id;
 	GtkTreeSortable *sortable;
+	GtkTreeModel *filter;
 
 	/* Get header window */
 	if (MODEST_IS_HEADER_WINDOW (parent_window)) {
@@ -613,7 +613,8 @@ launch_sort_headers_dialog (ModestWindow *parent_window,
 	sort_ids[sort_key] = TNY_HEADER_FLAG_PRIORITY_MASK;
 	priority_sort_id = sort_key;
 	
-	sortable = GTK_TREE_SORTABLE (gtk_tree_view_get_model (GTK_TREE_VIEW (header_view)));
+	filter = gtk_tree_view_get_model (GTK_TREE_VIEW (header_view));
+	sortable = GTK_TREE_SORTABLE (gtk_tree_model_filter_get_model (GTK_TREE_MODEL_FILTER (filter)));
 	/* Launch dialogs */
 	if (!gtk_tree_sortable_get_sort_column_id (sortable,
 						   &current_sort_colid, &current_sort_type)) {
@@ -910,12 +911,49 @@ modest_utils_create_country_model (void)
 	return model;
 }
 
+/**
+ * Update the territory depending on territory exceptions
+ * @param[in] territory The territory to be checked
+ * @return The resulting territory
+ */
+static const gchar *
+modest_utils_country_model_check_territory_exceptions (const gchar *territory)
+{
+	typedef struct {
+		const gchar *original;
+		const gchar *substitution;
+	} TerritoryException;
+
+	const gchar *result;
+	const TerritoryException *exception;
+
+	static const TerritoryException exceptions[] = {
+		{ "Great Britain", "United Kingdom" },
+		{ NULL, NULL }
+	};
+
+	result = territory;
+	exception = exceptions;
+
+	while (exception->original) {
+		if (0 == g_utf8_collate (exception->original, territory)) {
+			result = exception->substitution;
+			break;
+		}
+
+		/* move on to the next exception */
+		++exception;
+	}
+
+	return result;
+}
+
 void
 modest_utils_fill_country_model (GtkTreeModel *model, gint *locale_mcc)
 {
 	char line[MCC_FILE_MAX_LINE_LEN];
 	guint previous_mcc = 0;
-	gchar *territory;
+	const gchar *territory;
 	GHashTable *country_hash;
 	FILE *file;
 
@@ -927,7 +965,7 @@ modest_utils_fill_country_model (GtkTreeModel *model, gint *locale_mcc)
 	}
 
 	/* Get the territory specified for the current locale */
-	territory = nl_langinfo (_NL_IDENTIFICATION_TERRITORY);
+	territory = modest_utils_country_model_check_territory_exceptions (nl_langinfo (_NL_IDENTIFICATION_TERRITORY));
 
 	setlocale (LC_MESSAGES, "en_GB");
 
