@@ -87,6 +87,8 @@ static void row_count_changed (ModestAccountsWindow *self);
 static gboolean on_key_press(GtkWidget *widget,
 			     GdkEventKey *event,
 			     gpointer user_data);
+static void on_screen_changed(GdkScreen *screen,
+		              gpointer userdata);
 #endif
 static gboolean on_delete_event (GtkWidget *widget,
 				 GdkEvent *event,
@@ -112,8 +114,9 @@ struct _ModestAccountsWindowPrivate {
 									    ModestAccountsWindowPrivate))
 
 /* globals */
-static GtkWindowClass *parent_class = NULL;
+static ModestWindowParentClass *parent_class = NULL;
 static GtkWidget *pre_created_accounts_window = NULL;
+static gboolean pre_created_accounts_window_created = FALSE;
 
 /************************************************************************/
 
@@ -209,6 +212,7 @@ connect_signals (ModestAccountsWindow *self)
 {
 	ModestAccountsWindowPrivate *priv;
 	GtkTreeModel *model;
+	GdkScreen *screen;
 
 	priv = MODEST_ACCOUNTS_WINDOW_GET_PRIVATE(self);
 
@@ -224,7 +228,7 @@ connect_signals (ModestAccountsWindow *self)
 					   "progress-list-changed",
 					   G_CALLBACK (on_progress_list_changed), self);
 
-	model = gtk_tree_view_get_model (GTK_TREE_VIEW (priv->account_view));
+	model = modest_account_view_get_model (MODEST_ACCOUNT_VIEW (priv->account_view));
 
 	priv->sighandlers =
 		modest_signal_mgr_connect (priv->sighandlers,
@@ -244,6 +248,14 @@ connect_signals (ModestAccountsWindow *self)
 					   G_OBJECT (priv->new_message_button),
 					   "clicked",
 					   G_CALLBACK (modest_ui_actions_on_new_msg), self);
+
+	screen = gtk_widget_get_screen(GTK_WIDGET(self));
+
+	priv->sighandlers = 
+		modest_signal_mgr_connect (priv->sighandlers,
+					   G_OBJECT (screen), 
+					   "size-changed",
+			     		    G_CALLBACK (on_screen_changed), self);
 #endif
 
 	/* we don't register this in sighandlers, as it should be run
@@ -276,14 +288,11 @@ modest_accounts_window_new_real (void)
 	no_accounts_label = gtk_label_new (_("mcen_ia_noaccounts"));
 	
 	gtk_misc_set_alignment (GTK_MISC (no_accounts_label), 0.5, 0.5);
-#ifdef MODEST_TOOLKIT_HILDON2
-	hildon_helper_set_logical_font (no_accounts_label, "LargeSystemFont");
-#endif
-
 #ifdef MODEST_TOOLKIT_HILDON2
 	GdkPixbuf *new_message_pixbuf;
 	GtkWidget *empty_view_new_message_button;
 
+	hildon_helper_set_logical_font (no_accounts_label, "LargeSystemFont");
 	new_message_pixbuf = modest_platform_get_icon ("general_add", MODEST_ICON_SIZE_BIG);
 
 	empty_view_new_message_button = hildon_button_new (MODEST_EDITABLE_SIZE, HILDON_BUTTON_ARRANGEMENT_HORIZONTAL);
@@ -359,6 +368,7 @@ modest_accounts_window_new_real (void)
 	return MODEST_WINDOW(self);
 }
 
+
 ModestWindow *
 modest_accounts_window_new (void)
 {
@@ -366,6 +376,7 @@ modest_accounts_window_new (void)
 	ModestAccountsWindowPrivate *priv = NULL;
 #ifdef MODEST_TOOLKIT_HILDON2
 	HildonProgram *app;
+	GtkWidget *live_search;
 #endif
 
 	if (pre_created_accounts_window) {
@@ -373,9 +384,15 @@ modest_accounts_window_new (void)
 		pre_created_accounts_window = NULL;
 	} else {
 		self = modest_accounts_window_new_real ();
+		pre_created_accounts_window_created = TRUE;
 	}
 	priv = MODEST_ACCOUNTS_WINDOW_GET_PRIVATE(self);
 	priv->account_view  = GTK_WIDGET (modest_account_view_new (modest_runtime_get_account_mgr ()));
+#ifdef MODEST_TOOLKIT_HILDON2
+	live_search = modest_account_view_setup_live_search (MODEST_ACCOUNT_VIEW (priv->account_view));
+	hildon_live_search_widget_hook (HILDON_LIVE_SEARCH (live_search), GTK_WIDGET (self), priv->account_view);
+	gtk_box_pack_start (GTK_BOX (priv->box), live_search, FALSE, FALSE, 0);
+#endif
 
 #ifdef MODEST_TOOLKIT_HILDON2
 	GtkWidget *action_area_box;
@@ -608,17 +625,22 @@ row_count_changed (ModestAccountsWindow *self)
 	gint count;
 
 	priv = MODEST_ACCOUNTS_WINDOW_GET_PRIVATE (self);
-	model = gtk_tree_view_get_model (GTK_TREE_VIEW (priv->account_view));
+	model = modest_account_view_get_model (MODEST_ACCOUNT_VIEW (priv->account_view));
 
 	count = gtk_tree_model_iter_n_children (model, NULL);
-
 	if (count == 0) {
 		gtk_widget_hide (priv->account_view);
 		gtk_widget_show (priv->no_accounts_container);
+#ifdef MODEST_TOOLKIT_HILDON2
+		hildon_tree_view_set_action_area_visible (GTK_TREE_VIEW (priv->account_view), FALSE);
+#endif
 		g_debug ("%s: hiding accounts view", __FUNCTION__);
 	} else {
 		gtk_widget_hide (priv->no_accounts_container);
 		gtk_widget_show (priv->account_view);
+#ifdef MODEST_TOOLKIT_HILDON2
+		hildon_tree_view_set_action_area_visible (GTK_TREE_VIEW (priv->account_view), TRUE);
+#endif
 		g_debug ("%s: showing accounts view", __FUNCTION__);
 	}
 	gtk_container_child_set (GTK_CONTAINER(priv->box), priv->scrollable, 
@@ -697,9 +719,8 @@ on_queue_changed (ModestMailOperationQueue *queue,
 void 
 modest_accounts_window_pre_create (void)
 {
-	static gboolean pre_created = FALSE;
-	if (!pre_created) {
-		pre_created = TRUE;
+	if (!pre_created_accounts_window_created) {
+		pre_created_accounts_window_created = TRUE;
 		pre_created_accounts_window = GTK_WIDGET (modest_accounts_window_new_real ());
 	}
 }
@@ -731,6 +752,16 @@ on_key_press(GtkWidget *widget, GdkEventKey *event, gpointer user_data)
 
 	return FALSE;
 }
+
+static void
+on_screen_changed (GdkScreen *screen,
+                   gpointer   userdata) 
+{
+	ModestAccountsWindow *self = (ModestAccountsWindow *) userdata;
+	ModestAccountsWindowPrivate *priv = MODEST_ACCOUNTS_WINDOW_GET_PRIVATE (self);
+
+	gtk_widget_queue_resize(priv->new_message_button);
+}
 #endif
 
 static gboolean
@@ -757,3 +788,4 @@ on_delete_event (GtkWidget *widget,
 	return FALSE;
 
 }
+
