@@ -213,7 +213,7 @@ create_updating_page (ModestDefaultGlobalSettingsDialog *self)
 	ppriv->accounts_list = get_accounts_list ();
 	ppriv->default_account_selector = modest_toolkit_factory_create_selector (modest_runtime_get_toolkit_factory (),
 										  ppriv->accounts_list,
-										  g_str_equal);
+										  g_str_equal, TRUE);
 	if (ppriv->accounts_list == NULL) {
 		gtk_widget_set_sensitive (GTK_WIDGET (ppriv->default_account_selector), FALSE);
 	} else {
@@ -250,7 +250,7 @@ create_updating_page (ModestDefaultGlobalSettingsDialog *self)
 	 * so it can't know how to manage its memory. */
 	ppriv->msg_format_list = _modest_global_settings_dialog_get_msg_formats ();
 	ppriv->msg_format = modest_toolkit_factory_create_selector (modest_runtime_get_toolkit_factory (),
-								    ppriv->msg_format_list, g_int_equal);
+								    ppriv->msg_format_list, g_int_equal, TRUE);
 	if (GTK_IS_COMBO_BOX (ppriv->msg_format)) {
 		GtkWidget *caption;
 		caption = modest_toolkit_utils_create_vcaptioned (title_size_group,
@@ -276,6 +276,11 @@ create_updating_page (ModestDefaultGlobalSettingsDialog *self)
 									     _("mcen_fi_options_automatic_add"));
 	gtk_box_pack_start (GTK_BOX (vbox), ppriv->add_to_contacts, FALSE, FALSE, 0);
 
+	/* Tree view */
+	ppriv->tree_view = modest_toolkit_factory_create_check_button (modest_runtime_get_toolkit_factory (),
+									     _("mcen_fi_options_tree_view"));
+	gtk_box_pack_start (GTK_BOX (vbox), ppriv->tree_view, FALSE, FALSE, 0);
+
 	/* Separator label */
 	separator = gtk_label_new (_("mcen_ti_updating"));
 	attr_list = pango_attr_list_new ();
@@ -298,7 +303,7 @@ create_updating_page (ModestDefaultGlobalSettingsDialog *self)
 	 * so it can't know how to manage its memory. */ 
 	ppriv->connect_via_list = _modest_global_settings_dialog_get_connected_via ();
 	ppriv->connect_via = modest_toolkit_factory_create_selector (modest_runtime_get_toolkit_factory (),
-								     ppriv->connect_via_list, g_int_equal);
+								     ppriv->connect_via_list, g_int_equal, TRUE);
 	if (GTK_IS_COMBO_BOX (ppriv->connect_via)) {
 		GtkWidget *caption;
 		caption = modest_toolkit_utils_create_vcaptioned (title_size_group,
@@ -320,7 +325,7 @@ create_updating_page (ModestDefaultGlobalSettingsDialog *self)
 	 * so it can't know how to manage its memory. */ 
 	ppriv->update_interval_list = _modest_global_settings_dialog_get_update_interval ();
 	ppriv->update_interval = modest_toolkit_factory_create_selector (modest_runtime_get_toolkit_factory (),
-									 ppriv->update_interval_list, g_int_equal);
+									 ppriv->update_interval_list, g_int_equal, TRUE);
 	if (GTK_IS_COMBO_BOX (ppriv->update_interval)) {
 		GtkWidget *caption;
 		caption = modest_toolkit_utils_create_vcaptioned (title_size_group,
@@ -337,6 +342,7 @@ create_updating_page (ModestDefaultGlobalSettingsDialog *self)
 
 	scrollable = modest_toolkit_factory_create_scrollable (modest_runtime_get_toolkit_factory ());
 
+	g_object_set (scrollable, "mov-mode", HILDON_MOVEMENT_MODE_BOTH, NULL);
 	modest_scrollable_add_with_viewport (MODEST_SCROLLABLE (scrollable), vbox);
 	gtk_widget_show (vbox);
 	gtk_widget_show (scrollable);
@@ -482,6 +488,16 @@ modest_default_global_settings_dialog_load_settings (ModestGlobalSettingsDialog
 	modest_togglable_set_active (ppriv->add_to_contacts, checked);
 	ppriv->initial_state.add_to_contacts = checked;
 
+	/* Tree view */
+	checked = modest_conf_get_bool (conf, MODEST_CONF_TREE_VIEW, &error);
+	if (error) {
+		g_clear_error (&error);
+		error = NULL;
+		checked = FALSE;
+	}
+	modest_togglable_set_active (ppriv->tree_view, checked);
+	ppriv->initial_state.tree_view = checked;
+
 	/* Autoupdate */
 	checked = modest_conf_get_bool (conf, MODEST_CONF_AUTO_UPDATE, &error);
 	if (error) {
