@@ -482,6 +482,12 @@ TnyHeader* modest_header_view_get_header_at_pos (ModestHeaderView *header_view,
 GtkWidget *modest_header_view_setup_live_search (ModestHeaderView *self);
 #endif
 
+void modest_header_view_set_show_latest (ModestHeaderView *header_view,
+					 gint show_latest);
+
+gint modest_header_view_get_show_latest (ModestHeaderView *header_view);
+gint modest_header_view_get_not_latest (ModestHeaderView *header_view);
+
 G_END_DECLS
 
 
