@@ -49,10 +49,13 @@
 #include <modest-text-utils.h>
 #include <modest-ui-dimming-rules.h>
 #include <modest-tny-folder.h>
+#include <modest-tny-account.h>
 #include <tny-simple-list.h>
 #include <gdk/gdkkeysyms.h>
 #include <modest-isearch-toolbar.h>
 
+#define SHOW_LATEST_SIZE 250
+
 typedef enum {
 	CONTENTS_STATE_NONE = 0,
 	CONTENTS_STATE_EMPTY = 1,
@@ -73,9 +76,10 @@ struct _ModestHeaderWindowPrivate {
 	GtkWidget *empty_view;
 	GtkWidget *contents_view;
 	GtkWidget *top_vbox;
+#ifdef MODEST_TOOLKIT_HILDON2
 	GtkWidget *new_message_button;
 	GtkWidget *show_more_button;
-
+#endif
 	/* state bar */
 	ContentsState contents_state;
 
@@ -103,6 +107,7 @@ struct _ModestHeaderWindowPrivate {
 	/* weak refs */
 	GtkTreeModel *model_weak_ref;
 
+	gboolean limit_headers;
 	GtkWidget   *isearch_toolbar;
 };
 #define MODEST_HEADER_WINDOW_GET_PRIVATE(o)  (G_TYPE_INSTANCE_GET_PRIVATE((o), \
@@ -185,6 +190,8 @@ static gboolean on_key_press(GtkWidget *widget,
 					gpointer user_data);
 static void on_screen_changed(GdkScreen *screen,
 		              gpointer userdata);
+static void modest_header_window_show_more (GtkAction *action,
+					    gpointer userdata);
 #endif
 
 static void  isearch_toolbar_close  (GtkWidget *widget,
@@ -277,11 +284,18 @@ modest_header_window_init (ModestHeaderWindow *obj)
 	priv->queue_change_handler = 0;
 	priv->model_weak_ref = NULL;
 	priv->current_store_account = NULL;
+#ifdef MODEST_TOOLKIT_HILDON2
 	priv->new_message_button = NULL;
+	priv->show_more_button = NULL;
+#endif
 	priv->x_coord = 0;
 	priv->y_coord = 0;
 	priv->notify_model = 0;
+	priv->limit_headers = FALSE;
 
+	modest_window_mgr_register_help_id (modest_runtime_get_window_mgr(),
+					    GTK_WINDOW(obj),
+					    "applications_email_headerview");
 }
 
 static void
@@ -441,6 +455,11 @@ connect_signals (ModestHeaderWindow *self)
 					   G_OBJECT (priv->new_message_button),
 					   "clicked",
 					   G_CALLBACK (modest_ui_actions_on_new_msg), self);
+	priv->sighandlers =
+		modest_signal_mgr_connect (priv->sighandlers,
+					   G_OBJECT (priv->show_more_button),
+					   "clicked",
+					   G_CALLBACK (modest_header_window_show_more), self);
 
 	/* Delete using horizontal gesture */
 	/* DISABLED because it's unreliabile */
@@ -714,9 +733,26 @@ create_header_view (ModestWindow *self, TnyFolder *folder)
 	GtkWidget *header_view;
 	GtkWidget *delete_item, *mark_read_item, *mark_unread_item;
 	ModestHeaderWindowPrivate *priv;
+	TnyAccount *account;
+	ModestProtocolType protocol_type;
+
+	priv = MODEST_HEADER_WINDOW_GET_PRIVATE (self);
 
 	header_view  = modest_header_view_new (NULL, MODEST_HEADER_VIEW_STYLE_TWOLINES);
-	priv = MODEST_HEADER_WINDOW_GET_PRIVATE (self);
+
+	account = modest_tny_folder_get_account (folder);
+	priv->limit_headers = FALSE;
+	if (account) {
+		protocol_type = modest_tny_account_get_protocol_type (account);
+		if (modest_protocol_registry_protocol_type_has_tag (modest_runtime_get_protocol_registry (),
+								    protocol_type,
+								    MODEST_PROTOCOL_REGISTRY_STORE_LIMIT_HEADER_WINDOW)) {
+			priv->limit_headers = TRUE;
+		}
+		g_object_unref (account);
+	}
+	modest_header_view_set_show_latest (MODEST_HEADER_VIEW (header_view), priv->limit_headers?SHOW_LATEST_SIZE:0);
+
 	priv->notify_model = g_signal_connect ((GObject*) header_view, "notify::model",
 					       G_CALLBACK (on_header_view_model_changed), self);
 
@@ -790,6 +826,10 @@ create_empty_view (ModestWindow *self)
 #ifdef MODEST_TOOLKIT_HILDON2
 	GdkPixbuf *new_message_pixbuf;
 	GtkWidget *button = NULL;
+	GtkWidget *hbox = NULL;
+	ModestHeaderWindowPrivate *priv;
+
+	priv = MODEST_HEADER_WINDOW_GET_PRIVATE(self);
 	button = hildon_button_new (MODEST_EDITABLE_SIZE, 
 				    HILDON_BUTTON_ARRANGEMENT_HORIZONTAL);
 
@@ -799,7 +839,12 @@ create_empty_view (ModestWindow *self)
 				 gtk_image_new_from_pixbuf (new_message_pixbuf));
 	g_object_unref (new_message_pixbuf);
 	gtk_widget_show_all (button);
-	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
+
+	hbox = gtk_hbox_new (TRUE, 0);
+	gtk_widget_show (hbox);
+	gtk_box_pack_start (GTK_BOX (hbox), button, TRUE, TRUE, 0);
+
+	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 #endif
 
 	gtk_widget_show (vbox);
@@ -1029,6 +1074,16 @@ static void setup_menu (ModestHeaderWindow *self)
 				   MODEST_WINDOW_MENU_CALLBACK (modest_ui_actions_on_send_receive),
 				   MODEST_DIMMING_CALLBACK (modest_ui_dimming_rules_on_send_receive));
 #ifdef MODEST_TOOLKIT_HILDON2
+
+	priv->show_more_button = hildon_button_new (MODEST_EDITABLE_SIZE, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
+	hildon_button_set_title (HILDON_BUTTON (priv->show_more_button), _("mcen_va_more"));
+	hildon_button_set_alignment (HILDON_BUTTON (priv->show_more_button), 0.5, 0.5, 1.0, 1.0);
+	hildon_button_set_title_alignment (HILDON_BUTTON (priv->show_more_button), 0.5, 0.5);
+	hildon_button_set_value_alignment (HILDON_BUTTON (priv->show_more_button), 0.5, 0.5);
+
+	modest_window_add_item_to_menu (MODEST_WINDOW (self), GTK_WIDGET (priv->show_more_button), NULL);
+	gtk_widget_hide_all (priv->show_more_button);
+
 	modest_window_add_to_menu (MODEST_WINDOW (self),
 				   dngettext(GETTEXT_PACKAGE,
 					     "mcen_me_move_message",
@@ -1057,17 +1112,6 @@ static void setup_menu (ModestHeaderWindow *self)
 				   MODEST_WINDOW_MENU_CALLBACK (modest_ui_actions_on_details),
 				   MODEST_DIMMING_CALLBACK (modest_ui_dimming_rules_on_details));
 
-#ifdef MODEST_TOOLKIT_HILDON2
-	priv->show_more_button = hildon_button_new (MODEST_EDITABLE_SIZE, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
-	hildon_button_set_title (HILDON_BUTTON (priv->show_more_button), _("mcen_va_more"));
-	hildon_button_set_alignment (HILDON_BUTTON (priv->show_more_button), 0.5, 0.5, 1.0, 1.0);
-	hildon_button_set_title_alignment (HILDON_BUTTON (priv->show_more_button), 0.5, 0.5);
-	hildon_button_set_value_alignment (HILDON_BUTTON (priv->show_more_button), 0.5, 0.5);
-	modest_window_add_item_to_menu (MODEST_WINDOW (self), priv->show_more_button,
-					NULL);
-	gtk_widget_hide_all (priv->show_more_button);
-#endif
-
 	modest_window_add_to_menu (MODEST_WINDOW (self), _("mcen_me_outbox_cancelsend"), NULL,
 				   MODEST_WINDOW_MENU_CALLBACK (modest_ui_actions_cancel_send),
 				   MODEST_DIMMING_CALLBACK (modest_ui_dimming_rules_on_cancel_sending_all));
@@ -1086,6 +1130,11 @@ update_view (ModestHeaderWindow *self,
 	gboolean folder_empty = FALSE;
 	gboolean all_marked_as_deleted = FALSE;
 	TnyFolder *folder;
+	guint all_count;
+#ifdef MODEST_TOOLKIT_HILDON2
+	gchar *show_more_value;
+	guint visible;
+#endif
 
 	g_return_if_fail (MODEST_IS_HEADER_WINDOW(self));
 
@@ -1106,14 +1155,16 @@ update_view (ModestHeaderWindow *self,
 		changed = tny_folder_change_get_changed (change);
 		/* If something changes */
 		if ((changed) & TNY_FOLDER_CHANGE_CHANGED_ALL_COUNT)
-			folder_empty = (((guint) tny_folder_change_get_new_all_count (change)) == 0);
+			all_count = (guint) tny_folder_change_get_new_all_count (change);
 		else
-			folder_empty = (((guint) tny_folder_get_all_count (folder)) == 0);
+			all_count = (guint) tny_folder_get_all_count (folder);
 
+		folder_empty = (all_count == 0);
 		if ((changed) & TNY_FOLDER_CHANGE_CHANGED_EXPUNGED_HEADERS)
 			refilter = TRUE;
 	} else {
-		folder_empty = (((guint) tny_folder_get_all_count (folder)) == 0);
+		all_count = (guint) tny_folder_get_all_count (folder);
+		folder_empty = (all_count == 0);
 	}
 	g_object_unref (folder);
 
@@ -1126,6 +1177,24 @@ update_view (ModestHeaderWindow *self,
 
 	if (refilter)
 		modest_header_view_refilter (MODEST_HEADER_VIEW (priv->header_view));
+#ifdef MODEST_TOOLKIT_HILDON2
+	visible = modest_header_view_get_show_latest (MODEST_HEADER_VIEW (priv->header_view));
+
+	if (visible > 0 && all_count > 0 && visible < all_count && folder_empty) {
+		modest_header_view_set_show_latest (MODEST_HEADER_VIEW (priv->header_view), visible + SHOW_LATEST_SIZE);
+	}
+	if (visible > all_count)
+		visible = all_count;
+	if (visible == 0 || visible == all_count) {
+		gtk_widget_hide_all (priv->show_more_button);
+	} else {
+		gtk_widget_show_all (priv->show_more_button);
+	}
+	show_more_value = g_strdup_printf (_("mcen_va_more_toview"), visible, all_count);
+
+	hildon_button_set_value (HILDON_BUTTON (priv->show_more_button),
+				 show_more_value);
+#endif
 }
 
 static void 
@@ -1603,6 +1672,25 @@ on_screen_changed (GdkScreen *screen,
 
 	gtk_widget_queue_resize(priv->new_message_button);
 }
+
+static void
+modest_header_window_show_more (GtkAction *action, gpointer userdata)
+{
+	ModestHeaderWindow *self;
+	ModestHeaderWindowPrivate *priv = NULL;
+
+	self = MODEST_HEADER_WINDOW (userdata);
+	priv = MODEST_HEADER_WINDOW_GET_PRIVATE (self);
+	if (!priv->header_view)
+		return;
+
+	if (modest_header_view_get_not_latest (MODEST_HEADER_VIEW (priv->header_view)) > 0) {
+		modest_header_view_set_show_latest (MODEST_HEADER_VIEW (priv->header_view),
+						    modest_header_view_get_show_latest (MODEST_HEADER_VIEW (priv->header_view)) +
+						    SHOW_LATEST_SIZE);
+		update_view (self, NULL);
+	}
+}
 #endif
 
 #ifndef MODEST_TOOLKIT_HILDON2
@@ -1646,7 +1734,9 @@ isearch_toolbar_close (GtkWidget *widget,
 	/* Hide toolbar */
 	gtk_widget_hide (priv->isearch_toolbar);
 
+	modest_header_view_set_show_latest (MODEST_HEADER_VIEW (priv->header_view), priv->limit_headers?SHOW_LATEST_SIZE:0);
 	modest_header_view_set_filter_string (MODEST_HEADER_VIEW (priv->header_view), NULL);
+	update_view (obj, NULL);
 }
 
 static void
@@ -1654,9 +1744,17 @@ isearch_toolbar_search (GtkWidget *widget,
 			ModestHeaderWindow *obj)
 {
 	ModestHeaderWindowPrivate *priv = MODEST_HEADER_WINDOW_GET_PRIVATE (obj);
+	const gchar *current_search = NULL;
+
+	current_search = modest_isearch_toolbar_get_search (MODEST_ISEARCH_TOOLBAR (priv->isearch_toolbar));
 
 	/* TODO: set filter */
 	modest_header_view_set_filter_string (MODEST_HEADER_VIEW (priv->header_view), 
-					      modest_isearch_toolbar_get_search (MODEST_ISEARCH_TOOLBAR (priv->isearch_toolbar)));
-
+					      current_search);
+	if (current_search == NULL) {
+		modest_header_view_set_show_latest (MODEST_HEADER_VIEW (priv->header_view), priv->limit_headers?SHOW_LATEST_SIZE:0);
+	} else {
+		modest_header_view_set_show_latest (MODEST_HEADER_VIEW (priv->header_view), 0);
+	}
+	update_view (obj, NULL);
 }
