@@ -84,6 +84,8 @@ static void on_activity_changed (ModestFolderView *view,
 static gboolean on_key_press(GtkWidget *widget,
 			     GdkEventKey *event,
 			     gpointer user_data);
+static void on_screen_changed(GdkScreen *screen,
+		              gpointer userdata);
 #endif
 
 typedef struct _ModestMailboxesWindowPrivate ModestMailboxesWindowPrivate;
@@ -239,6 +241,7 @@ static void
 connect_signals (ModestMailboxesWindow *self)
 {
 	ModestMailboxesWindowPrivate *priv;
+	GdkScreen *screen;
 
 	priv = MODEST_MAILBOXES_WINDOW_GET_PRIVATE(self);
 
@@ -269,6 +272,14 @@ connect_signals (ModestMailboxesWindow *self)
 					   G_CALLBACK (modest_ui_actions_on_new_msg), self);
 
 #ifdef MODEST_TOOLKIT_HILDON2
+	screen = gtk_widget_get_screen(GTK_WIDGET(self));
+
+	priv->sighandlers = 
+		modest_signal_mgr_connect (priv->sighandlers,
+					   G_OBJECT (screen), 
+					   "size-changed",
+			     		    G_CALLBACK (on_screen_changed), self);
+
 	/* connect window keys -> priv->folder_view scroll here? */
 	g_signal_connect(G_OBJECT(self), "key-press-event",
 			G_CALLBACK(on_key_press), self);
@@ -283,6 +294,9 @@ modest_mailboxes_window_new (const gchar *account)
 	GdkPixbuf *window_icon;
 	GtkWidget *scrollable;
 	GtkWidget *top_alignment;
+#ifdef MODEST_TOOLKIT_HILDON2
+	GtkWidget *live_search;
+#endif
 	
 	self  = MODEST_MAILBOXES_WINDOW(g_object_new(MODEST_TYPE_MAILBOXES_WINDOW, NULL));
 	priv = MODEST_MAILBOXES_WINDOW_GET_PRIVATE(self);
@@ -295,6 +309,10 @@ modest_mailboxes_window_new (const gchar *account)
 				  self);
 
 	priv->folder_view  = modest_platform_create_folder_view (NULL);
+#ifdef MODEST_TOOLKIT_HILDON2
+	live_search = modest_folder_view_setup_live_search (MODEST_FOLDER_VIEW (priv->folder_view));
+	hildon_live_search_widget_hook (HILDON_LIVE_SEARCH (live_search), GTK_WIDGET (self), priv->folder_view);
+#endif
 	modest_folder_view_set_cell_style (MODEST_FOLDER_VIEW (priv->folder_view),
 					   MODEST_FOLDER_VIEW_CELL_STYLE_COMPACT);
 	modest_folder_view_set_filter (MODEST_FOLDER_VIEW (priv->folder_view), 
@@ -304,7 +322,7 @@ modest_mailboxes_window_new (const gchar *account)
 	GtkWidget *action_area_box;
 	GdkPixbuf *new_message_pixbuf;
 	action_area_box = hildon_tree_view_get_action_area_box (GTK_TREE_VIEW (priv->folder_view));
-	priv->new_message_button = hildon_button_new (0, HILDON_BUTTON_ARRANGEMENT_HORIZONTAL);
+	priv->new_message_button = hildon_button_new (MODEST_EDITABLE_SIZE, HILDON_BUTTON_ARRANGEMENT_HORIZONTAL);
 
 	hildon_button_set_title (HILDON_BUTTON (priv->new_message_button), _("mcen_ti_new_message"));
 	new_message_pixbuf = modest_platform_get_icon ("general_add", MODEST_ICON_SIZE_BIG);
@@ -323,11 +341,14 @@ modest_mailboxes_window_new (const gchar *account)
 	priv->top_vbox = gtk_vbox_new (0, FALSE);
 	top_alignment = gtk_alignment_new (0.0, 0.0, 1.0, 1.0);
 	gtk_alignment_set_padding (GTK_ALIGNMENT (top_alignment), 
-				   0, 0, 
+				   MODEST_MARGIN_HALF, 0, 
 				   MODEST_MARGIN_DOUBLE, MODEST_MARGIN_DOUBLE);
 
 	gtk_container_add (GTK_CONTAINER (scrollable), priv->folder_view);
 	gtk_box_pack_end (GTK_BOX (priv->top_vbox), scrollable, TRUE, TRUE, 0);
+#ifdef MODEST_TOOLKIT_HILDON2
+	gtk_box_pack_end (GTK_BOX (priv->top_vbox), live_search, FALSE, FALSE, 0);
+#endif
 	gtk_container_add (GTK_CONTAINER (top_alignment), priv->top_vbox);
 	gtk_container_add (GTK_CONTAINER (self), top_alignment);
 
@@ -465,6 +486,8 @@ on_mailbox_activated (ModestFolderView *mailboxes_view,
 		return;
 
 	new_window = GTK_WIDGET (modest_folder_window_new (NULL));
+	active_account = modest_window_get_active_account (MODEST_WINDOW (self));
+	modest_window_set_active_account (MODEST_WINDOW (new_window), active_account);
 	registered = modest_window_mgr_register_window (modest_runtime_get_window_mgr (), 
 							MODEST_WINDOW (new_window),
 							MODEST_WINDOW (self));
@@ -663,4 +686,14 @@ on_key_press(GtkWidget *widget, GdkEventKey *event, gpointer user_data)
 
 	return FALSE;
 }
+
+static void
+on_screen_changed (GdkScreen *screen,
+                   gpointer   userdata) 
+{
+	ModestMailboxesWindow *self = (ModestMailboxesWindow *) userdata;
+	ModestMailboxesWindowPrivate *priv = MODEST_MAILBOXES_WINDOW_GET_PRIVATE (self);
+
+	gtk_widget_queue_resize(priv->new_message_button);
+}
 #endif
